@@ -5,6 +5,10 @@ from typing import List, Optional, Union
 from funcy import distinct
 from git import Repo
 
+from gto.commit_message_generator import (
+    generate_annotate_commit_message,
+    generate_remove_commit_message,
+)
 from gto.constants import (
     ARTIFACT,
     ASSIGNMENTS_PER_VERSION,
@@ -19,7 +23,12 @@ from gto.constants import (
 )
 from gto.exceptions import NoRepo, NotImplementedInGTO, WrongArgs
 from gto.ext import EnrichmentInfo
-from gto.git_utils import git_clone_remote_repo
+from gto.git_utils import (
+    clone_on_remote_repo,
+    commit_produced_changes_on_commit,
+    push_on_push,
+    set_push_on_remote_repo,
+)
 from gto.index import (
     EnrichmentManager,
     FileIndexManager,
@@ -54,12 +63,16 @@ def _get_state(repo: Union[str, Repo]):
     return GitRegistry.from_repo(repo).get_state()
 
 
-@git_clone_remote_repo
+@clone_on_remote_repo
 def get_stages(repo: Union[str, Repo], allowed: bool = False, used: bool = False):
     return GitRegistry.from_repo(repo).get_stages(allowed=allowed, used=used)
 
 
 # TODO: make this work the same as CLI version
+@set_push_on_remote_repo
+@clone_on_remote_repo
+@push_on_push
+@commit_produced_changes_on_commit(message_generator=generate_annotate_commit_message)
 def annotate(
     repo: Union[str, Repo],
     name: str,
@@ -68,6 +81,8 @@ def annotate(
     must_exist: bool = False,
     labels: List[str] = None,
     description: str = "",
+    commit: bool = False,  # pylint: disable=unused-argument
+    push: bool = False,  # pylint: disable=unused-argument
     # update: bool = False,
 ):
     """Add an artifact to the Index"""
@@ -82,11 +97,22 @@ def annotate(
     )
 
 
-def remove(repo: Union[str, Repo], name: str):
+@set_push_on_remote_repo
+@clone_on_remote_repo
+@push_on_push
+@commit_produced_changes_on_commit(message_generator=generate_remove_commit_message)
+def remove(
+    repo: Union[str, Repo],
+    name: str,
+    commit: bool = False,
+    push: bool = False,
+):  # pylint: disable=unused-argument
     """Remove an artifact from the Index"""
     return init_index_manager(path=repo).remove(name)
 
 
+@set_push_on_remote_repo
+@clone_on_remote_repo
 def register(
     repo: Union[str, Repo],
     name: str,
@@ -98,6 +124,7 @@ def register(
     bump_major: bool = False,
     bump_minor: bool = False,
     bump_patch: bool = False,
+    push: bool = False,
     stdout: bool = False,
     author: Optional[str] = None,
     author_email: Optional[str] = None,
@@ -113,12 +140,15 @@ def register(
         bump_major=bump_major,
         bump_minor=bump_minor,
         bump_patch=bump_patch,
+        push=push,
         stdout=stdout,
         author=author,
         author_email=author_email,
     )
 
 
+@set_push_on_remote_repo
+@clone_on_remote_repo
 def assign(
     repo: Union[str, Repo],
     name: str,
@@ -129,6 +159,7 @@ def assign(
     message: Optional[str] = None,
     simple: bool = False,
     force: bool = False,
+    push: bool = False,
     skip_registration: bool = False,
     stdout: bool = False,
     author: Optional[str] = None,
@@ -144,6 +175,7 @@ def assign(
         message=message,
         simple=simple,
         force=force,
+        push=push,
         skip_registration=skip_registration,
         stdout=stdout,
         author=author,
@@ -151,6 +183,8 @@ def assign(
     )
 
 
+@set_push_on_remote_repo
+@clone_on_remote_repo
 def unassign(
     repo: Union[str, Repo],
     name: str,
@@ -162,6 +196,7 @@ def unassign(
     simple: Optional[bool] = None,
     force: bool = False,
     delete: bool = False,
+    push: bool = False,
     author: Optional[str] = None,
     author_email: Optional[str] = None,
 ):
@@ -175,11 +210,14 @@ def unassign(
         simple=simple if simple is not None else False,
         force=force,
         delete=delete,
+        push=push,
         author=author,
         author_email=author_email,
     )
 
 
+@set_push_on_remote_repo
+@clone_on_remote_repo
 def deregister(
     repo: Union[str, Repo],
     name: str,
@@ -190,6 +228,7 @@ def deregister(
     simple: Optional[bool] = None,
     force: bool = False,
     delete: bool = False,
+    push: bool = False,
     author: Optional[str] = None,
     author_email: Optional[str] = None,
 ):
@@ -202,11 +241,14 @@ def deregister(
         simple=simple if simple is not None else True,
         force=force,
         delete=delete,
+        push=push,
         author=author,
         author_email=author_email,
     )
 
 
+@set_push_on_remote_repo
+@clone_on_remote_repo
 def deprecate(
     repo: Union[str, Repo],
     name: str,
@@ -215,6 +257,7 @@ def deprecate(
     simple: Optional[bool] = None,
     force: bool = False,
     delete: bool = False,
+    push: bool = False,
     author: Optional[str] = None,
     author_email: Optional[str] = None,
 ):
@@ -225,6 +268,7 @@ def deprecate(
         simple=simple if simple is not None else True,
         force=force,
         delete=delete,
+        push=push,
         author=author,
         author_email=author_email,
     )
@@ -263,14 +307,14 @@ def find_versions_in_stage(
     )
 
 
-@git_clone_remote_repo
+@clone_on_remote_repo
 def check_ref(repo: Union[str, Repo], ref: str):
     """Find out what have been registered/assigned in the provided ref"""
     reg = GitRegistry.from_repo(repo)
     return reg.check_ref(ref)
 
 
-@git_clone_remote_repo
+@clone_on_remote_repo
 def show(
     repo: Union[str, Repo],
     name: Optional[str] = None,
@@ -464,6 +508,7 @@ def _show_versions(  # pylint: disable=too-many-locals
     return versions_, "keys"
 
 
+@clone_on_remote_repo
 def describe(
     repo: Union[str, Repo], name: str, rev: str = None
 ) -> List[EnrichmentInfo]:
@@ -478,7 +523,7 @@ def describe(
     raise NotImplementedError
 
 
-@git_clone_remote_repo
+@clone_on_remote_repo
 def history(
     repo: Union[str, Repo],
     artifact: str = None,
