@@ -18,7 +18,16 @@ from gto.constants import (
     VersionSort,
 )
 from gto.exceptions import GTOException, NotImplementedInGTO, WrongArgs
-from gto.ui import EMOJI_FAIL, EMOJI_GTO, EMOJI_OK, bold, cli_echo, color, echo
+from gto.ui import (
+    EMOJI_FAIL,
+    EMOJI_GTO,
+    EMOJI_OK,
+    bold,
+    cli_echo,
+    color,
+    echo,
+    stderr_echo,
+)
 from gto.utils import format_echo, make_ready_to_serialize
 
 
@@ -209,7 +218,7 @@ option_repo = Option(
     ".",
     "-r",
     "--repo",
-    help="Repository to use",
+    help="Local or remote repository",
     show_default=True,
 )
 option_all_branches = Option(
@@ -350,6 +359,26 @@ option_table = Option(
     help="Print output in table format",
     show_default=True,
 )
+option_push_tag = Option(
+    False,
+    "--push",
+    is_flag=True,
+    help="Push created tag automatically (experimental)",
+)
+
+option_commit = Option(
+    False,
+    "--commit",
+    is_flag=True,
+    help="Automatically commit changes due to this command (experimental)",
+)
+
+option_push_commit = Option(
+    False,
+    "--push",
+    is_flag=True,
+    help="Push created commit automatically (experimental) - will set commit=True",
+)
 
 
 @app.callback("gto", invoke_without_command=True, no_args_is_help=True)
@@ -414,14 +443,14 @@ def gto_command(*args, section="other", aliases=None, parent=app, **kwargs):
                 error = str(type(e))
                 if ctx.obj["traceback"]:
                     raise
-                with cli_echo():
+                with stderr_echo():
                     echo(EMOJI_FAIL + color(str(e), col=typer.colors.RED))
                 raise typer.Exit(1) from e
             except Exception as e:  # pylint: disable=broad-except
                 error = str(type(e))
                 if ctx.obj["traceback"]:
                     raise
-                with cli_echo():
+                with stderr_echo():
                     echo(
                         (
                             EMOJI_FAIL
@@ -457,6 +486,8 @@ def annotate(
     ),
     label: List[str] = Option(None, "--label", help="Labels to add to artifact"),
     description: str = Option("", "-d", "--description", help="Artifact description"),
+    commit: bool = option_commit,
+    push: bool = option_push_commit,
     # update: bool = Option(
     #     False, "-u", "--update", is_flag=True, help="Update artifact if it exists"
     # ),
@@ -474,18 +505,25 @@ def annotate(
         must_exist=must_exist,
         labels=label,
         description=description,
+        commit=commit,
+        push=push,
         # update=update,
     )
 
 
 @gto_command(section=CommandGroups.enriching)
-def remove(repo: str = option_repo, name: str = arg_name):
+def remove(
+    repo: str = option_repo,
+    name: str = arg_name,
+    commit: bool = option_commit,
+    push: bool = option_push_commit,
+):
     """Remove the enrichment for given artifact
 
     Examples:
          $ gto remove nn
     """
-    gto.api.remove(repo, name)
+    gto.api.remove(repo, name, commit, push)
 
 
 @gto_command(section=CommandGroups.modifying)
@@ -508,6 +546,7 @@ def register(
     bump_patch: bool = Option(
         False, "--bump-patch", is_flag=True, help="Bump patch version"
     ),
+    push: bool = option_push_tag,
 ):
     """Create an artifact version to signify an important, published or released iteration
 
@@ -535,6 +574,7 @@ def register(
         bump_major=bump_major,
         bump_minor=bump_minor,
         bump_patch=bump_patch,
+        push=push,
         stdout=True,
     )
 
@@ -553,6 +593,7 @@ def assign(
     message: Optional[str] = option_message,
     simple: str = option_simple,
     force: bool = option_force,
+    push: bool = option_push_tag,
     skip_registration: bool = Option(
         False,
         "--sr",
@@ -595,6 +636,7 @@ def assign(
         message=message,
         simple=simple,  # type: ignore
         force=force,
+        push=push,
         skip_registration=skip_registration,
         stdout=True,
     )
@@ -610,6 +652,7 @@ def deprecate(
     simple: str = option_simple,
     force: bool = option_force,
     delete: bool = option_delete,
+    push: bool = option_push_tag,
 ):
     """Deprecate artifact, deregister a version, or unassign a stage
 
@@ -633,6 +676,7 @@ def deprecate(
             simple=simple,  # type: ignore
             force=force,
             delete=delete,
+            push=push,
             stdout=True,
         )
     elif version:
@@ -644,6 +688,7 @@ def deprecate(
             simple=simple,  # type: ignore
             force=force,
             delete=delete,
+            push=push,
             stdout=True,
         )
     else:
@@ -654,6 +699,7 @@ def deprecate(
             simple=simple,  # type: ignore
             force=force,
             delete=delete,
+            push=push,
             stdout=True,
         )
 
