@@ -107,7 +107,7 @@ class UnknownStage(GTOException):
         super().__init__(self.message)
 
 
-class NoActivePromotion(GTOException):
+class NoActiveAssignment(GTOException):
     _message = "No version in stage '{stage}' was found for '{name}'"
 
     def __init__(self, stage, name) -> None:
@@ -115,6 +115,16 @@ class NoActivePromotion(GTOException):
         super().__init__(self.message)
 
 
+class NoStageForVersion(GTOException):
+    _message = "The artifact '{artifact}' version '{version}' is not in stage '{stage}'"
+
+    def __init__(self, artifact, version, stage) -> None:
+        self.message = self._message.format(
+            artifact=artifact, version=version, stage=stage
+        )
+        super().__init__(self.message)
+
+
 class RefNotFound(GTOException):
     _message = "Ref '{ref}' was not found in the repository history"
 
@@ -123,6 +133,10 @@ class RefNotFound(GTOException):
         super().__init__(self.message)
 
 
+class AmbiguousArg(GTOException):
+    pass
+
+
 class InvalidVersion(GTOException):
     pass
 
@@ -171,6 +185,14 @@ class TagExists(GTOException):
         super().__init__(self.message)
 
 
+class TagNotFound(GTOException):
+    message = "tag '{name}' is not found"
+
+    def __init__(self, name) -> None:
+        self.message = self.message.format(name=name)
+        super().__init__(self.message)
+
+
 class ValidationError(GTOException):
     pass
 
