@@ -1,5 +1,6 @@
 import logging
 import os
+from pathlib import Path
 from typing import Optional, TypeVar, Union
 
 import git
@@ -30,6 +31,7 @@ from gto.exceptions import (
     VersionExistsForCommit,
     WrongArgs,
 )
+from gto.git_utils import git_push_tag
 from gto.index import EnrichmentManager
 from gto.tag import (
     TagArtifactManager,
@@ -136,6 +138,7 @@ class GitRegistry(BaseModel):
         bump_major=False,
         bump_minor=False,
         bump_patch=False,
+        push=False,
         stdout=False,
         author: Optional[str] = None,
         author_email: Optional[str] = None,
@@ -195,7 +198,7 @@ class GitRegistry(BaseModel):
         )
         if stdout:
             echo(f"Created git tag '{tag}' that registers version")
-            self._echo_git_suggestion(tag)
+        self._push_tag_or_echo_reminder(tag_name=tag, push=push, stdout=stdout)
         return self._return_event(tag)
 
     def deregister(  # pylint: disable=too-many-locals
@@ -207,6 +210,7 @@ class GitRegistry(BaseModel):
         simple=None,
         force=False,
         delete=False,
+        push: bool = False,
         stdout=False,
         author: Optional[str] = None,
         author_email: Optional[str] = None,
@@ -243,7 +247,7 @@ class GitRegistry(BaseModel):
                     if hasattr(e, "tag")
                 ]
             )
-            return self._delete_tags(tags, stdout=stdout)
+            return self._delete_tags(tags, stdout=stdout, push=push)
 
         tag = self.version_manager.deregister(
             name,
@@ -256,7 +260,9 @@ class GitRegistry(BaseModel):
         )
         if stdout:
             echo(f"Created git tag '{tag}' that deregisters version")
-            self._echo_git_suggestion(tag)
+        self._push_tag_or_echo_reminder(
+            tag_name=tag, push=push, stdout=stdout, delete=delete
+        )
         return self._return_event(tag)
 
     def assign(  # pylint: disable=too-many-locals
@@ -269,6 +275,7 @@ class GitRegistry(BaseModel):
         message=None,
         simple=False,
         force=False,
+        push: bool = False,
         skip_registration=False,
         stdout=False,
         author: Optional[str] = None,
@@ -302,7 +309,12 @@ class GitRegistry(BaseModel):
             else:
                 if not skip_registration:
                     self.register(
-                        name, version=name_version, ref=ref, simple=True, stdout=stdout
+                        name,
+                        version=name_version,
+                        ref=ref,
+                        simple=True,
+                        stdout=stdout,
+                        push=push,
                     )
                 found_version = self.find_artifact(name, create_new=True).find_version(
                     commit_hexsha=ref, create_new=True
@@ -314,7 +326,7 @@ class GitRegistry(BaseModel):
             and any(vstage.stage == stage for vstage in found_version.get_vstages())
         ):
             raise WrongArgs(
-                f"Version '{found_version.version}' is already in stage '{stage}. Use the '--force' flag to create a new Git tag nevertheless."
+                f"Version '{found_version.version}' is already in stage '{stage}'. Use the '--force' flag to create a new Git tag nevertheless."
             )
         # TODO: getting tag name as a result and using it
         # is leaking implementation details in base module
@@ -337,7 +349,7 @@ class GitRegistry(BaseModel):
             echo(
                 f"Created git tag '{tag}' that assigns stage to version '{found_version.version}'"
             )
-            self._echo_git_suggestion(tag)
+        self._push_tag_or_echo_reminder(tag_name=tag, push=push, stdout=stdout)
         return self._return_event(tag)
 
     def unassign(  # pylint: disable=too-many-locals
@@ -350,6 +362,7 @@ class GitRegistry(BaseModel):
         simple=False,
         force=False,
         delete=False,
+        push: bool = False,
         stdout=False,
         author: Optional[str] = None,
         author_email: Optional[str] = None,
@@ -374,7 +387,7 @@ class GitRegistry(BaseModel):
                     if hasattr(e, "tag") and hasattr(e, "stage") and e.stage == stage
                 ]
             )
-            return self._delete_tags(tags, stdout=stdout)
+            return self._delete_tags(tags, push=push, stdout=stdout)
 
         # TODO: getting tag name as a result and using it
         # is leaking implementation details in base module
@@ -394,7 +407,9 @@ class GitRegistry(BaseModel):
             echo(
                 f"Created git tag '{tag}' that unassigns stage from version '{found_version.version}'"
             )
-            self._echo_git_suggestion(tag)
+        self._push_tag_or_echo_reminder(
+            tag_name=tag, push=push, stdout=stdout, delete=delete
+        )
         return self._return_event(tag)
 
     def deprecate(
@@ -405,6 +420,7 @@ class GitRegistry(BaseModel):
         simple=False,
         force=False,
         delete=False,
+        push: bool = False,
         stdout=False,
         author: Optional[str] = None,
         author_email: Optional[str] = None,
@@ -421,7 +437,7 @@ class GitRegistry(BaseModel):
                     if hasattr(e, "tag")
                 ]
             )
-            return self._delete_tags(tags, stdout=stdout)
+            return self._delete_tags(tags, stdout=stdout, push=push)
         if ref is None:
             if name in self.get_artifacts():
                 ref = self.find_artifact(name=name).get_events()[0].commit_hexsha
@@ -437,7 +453,9 @@ class GitRegistry(BaseModel):
         )
         if stdout:
             echo(f"Created git tag '{tag}' that deprecates artifact")
-            self._echo_git_suggestion(tag)
+        self._push_tag_or_echo_reminder(
+            tag_name=tag, push=push, stdout=stdout, delete=delete
+        )
         return self._return_event(tag)
 
     def _check_args(self, name, version, ref, stage=None):
@@ -466,17 +484,20 @@ class GitRegistry(BaseModel):
     @staticmethod
     def _echo_git_suggestion(tag):
         echo("To push the changes upstream, run:")
-        echo(f"    git push {tag}")
+        echo(f"    git push origin {tag}")
 
-    def _delete_tags(self, tags, stdout):
+    def _delete_tags(self, tags, stdout, push: bool):
         tags = list(tags)
         for tag in tags:
             delete_tag(self.repo, tag)
             if stdout:
                 echo(f"Deleted git tag '{tag}'")
-        if stdout:
-            echo("To push the changes upstream, run:")
-            echo(f"    git push {' '.join(tags)} --delete".replace("!", "/!"))
+            self._push_tag_or_echo_reminder(
+                tag_name=tag,
+                push=push,
+                stdout=stdout,
+                delete=True,
+            )
 
     def check_ref(self, ref: str):
         "Find out what was registered/assigned in this ref"
@@ -554,3 +575,23 @@ class GitRegistry(BaseModel):
             return self._get_allowed_stages()
         # if stages aren't set in config, return those in use
         return self._get_used_stages()
+
+    def _push_tag_or_echo_reminder(
+        self, tag_name: str, push: bool, stdout: bool, delete: bool = False
+    ) -> None:
+        if push:
+            if stdout:
+                echo(
+                    f"Running `git push{' --delete ' if delete else ' '}origin {tag_name}`"
+                )
+            git_push_tag(
+                repo_path=Path(self.repo.git_dir).parent.as_posix(),
+                tag_name=tag_name,
+                delete=delete,
+            )
+            if stdout:
+                echo(
+                    f"Successfully {'deleted' if delete else 'pushed'} git tag {tag_name} on remote."
+                )
+        elif stdout:
+            self._echo_git_suggestion(tag_name)
