@@ -1,36 +1,56 @@
 # pylint: disable=unused-variable, redefined-outer-name
 from typing import Callable, Optional, Tuple
+from unittest import mock
 
 import git
 import pytest
 import typer
 from packaging import version
 from typer.main import get_command_from_info
-from typer.testing import CliRunner
 
 from gto.api import _get_index
 from gto.cli import app
+from gto.exceptions import GTOException
+from tests.conftest import Runner
 
 from .utils import check_obj
 
 
-def _check_successful_cmd(cmd: str, args: list, expected_stdout: Optional[str]):
-    runner = CliRunner()
-    result = runner.invoke(app, [cmd] + args)
-    assert result.exit_code == 0, (result.output, result.exception)
+def _check_output_contains(output: str, search_value: str) -> bool:
+    return search_value in output
+
+
+def _check_output_exact_match(output: str, search_value: str) -> bool:
+    return search_value == output
+
+
+def _check_successful_cmd(
+    cmd: str,
+    args: list,
+    expected_stdout: Optional[str],
+    search_func: Optional[Callable] = _check_output_exact_match,
+):
+    runner = Runner()
+    result = runner.invoke([cmd] + args)
+    assert result.exit_code == 0, (result.stdout, result.stderr, result.exception)
     if expected_stdout is not None:
         if len(expected_stdout):
-            assert len(result.output) > 0, "Output is empty, but should not be"
-        assert result.output == expected_stdout
+            assert len(result.stdout) > 0, "Output is empty, but should not be"
+        assert search_func(result.stdout, expected_stdout)
 
 
-def _check_failing_cmd(cmd: str, args: list, expected_stderr: str):
-    runner = CliRunner()
-    result = runner.invoke(app, [cmd] + args)
-    assert result.exit_code != 0, (result.output, result.exception)
+def _check_failing_cmd(
+    cmd: str,
+    args: list,
+    expected_stderr: str,
+    search_func: Optional[Callable] = _check_output_exact_match,
+):
+    runner = Runner()
+    result = runner.invoke([cmd] + args)
+    assert result.exit_code != 0, (result.stdout, result.stderr, result.exception)
     if expected_stderr is not None:
-        assert len(result.output) > 0, "Output is empty, but should not be"
-    assert result.output == expected_stderr
+        assert len(result.stderr) > 0, "Output is empty, but should not be"
+    assert search_func(result.stderr, expected_stderr)
 
 
 @pytest.fixture
@@ -282,7 +302,7 @@ def test_register(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "a1"],
         "Created git tag 'a1@v0.0.1' that registers version\n"
         "To push the changes upstream, run:\n"
-        "    git push a1@v0.0.1\n",
+        "    git push origin a1@v0.0.1\n",
     )
 
     _check_successful_cmd(
@@ -290,7 +310,7 @@ def test_register(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "a2", "--version", "v1.2.3"],
         "Created git tag 'a2@v1.2.3' that registers version\n"
         "To push the changes upstream, run:\n"
-        "    git push a2@v1.2.3\n",
+        "    git push origin a2@v1.2.3\n",
     )
 
     _check_successful_cmd(
@@ -298,7 +318,7 @@ def test_register(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "a2", "v1.2.3"],
         "Created git tag 'a2@v1.2.3!' that deregisters version\n"
         "To push the changes upstream, run:\n"
-        "    git push a2@v1.2.3!\n",
+        "    git push origin a2@v1.2.3!\n",
     )
 
     _check_successful_cmd(
@@ -306,7 +326,7 @@ def test_register(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "a2", "--simple", "false"],
         "Created git tag 'a2@v1.2.3#1' that registers version\n"
         "To push the changes upstream, run:\n"
-        "    git push a2@v1.2.3#1\n",
+        "    git push origin a2@v1.2.3#1\n",
     )
 
     _check_failing_cmd(
@@ -324,7 +344,7 @@ def test_assign(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "nn1"],
         "Created git tag 'nn1@v0.0.1' that registers version\n"
         "To push the changes upstream, run:\n"
-        "    git push nn1@v0.0.1\n",
+        "    git push origin nn1@v0.0.1\n",
     )
     # this check depends on the previous one
     _check_successful_cmd(
@@ -332,7 +352,7 @@ def test_assign(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "nn1", "HEAD", "--stage", "prod"],
         "Created git tag 'nn1#prod#1' that assigns stage to version 'v0.0.1'\n"
         "To push the changes upstream, run:\n"
-        "    git push nn1#prod#1\n",
+        "    git push origin nn1#prod#1\n",
     )
     # this check depends on the previous assignment
     _check_failing_cmd(
@@ -370,8 +390,26 @@ def test_assign(repo_with_commit: Tuple[git.Repo, Callable]):
         ["-r", repo.working_dir, "nn2", "HEAD", "--stage", "prod"],
         "Created git tag 'nn2@v0.0.1' that registers version\n"
         "To push the changes upstream, run:\n"
-        "    git push nn2@v0.0.1\n"
+        "    git push origin nn2@v0.0.1\n"
         "Created git tag 'nn2#prod#1' that assigns stage to version 'v0.0.1'\n"
         "To push the changes upstream, run:\n"
-        "    git push nn2#prod#1\n",
+        "    git push origin nn2#prod#1\n",
     )
+
+
+GTO_EXCEPTION_MESSAGE = "Test GTOException Message"
+
+
+def test_stderr_gto_exception():
+    # patch gto show to throw gto exception.
+    with mock.patch("gto.api.show", side_effect=GTOException(GTO_EXCEPTION_MESSAGE)):
+        _check_failing_cmd("show", [], GTO_EXCEPTION_MESSAGE, _check_output_contains)
+
+
+EXCEPTION_MESSAGE = "Test Exception Message"
+
+
+def test_stderr_exception():
+    # patch gto show to throw exception.
+    with mock.patch("gto.api.show", side_effect=Exception(EXCEPTION_MESSAGE)):
+        _check_failing_cmd("show", [], EXCEPTION_MESSAGE, _check_output_contains)
