@@ -1,8 +1,17 @@
 """TODO: break this file into multiple test/files"""
 # pylint: disable=unused-variable, too-many-locals, too-many-statements
 import gto
-from gto.base import BaseArtifact, BaseAssignment, BaseVersion
-from tests.utils import _check_obj
+from gto.base import (
+    Artifact,
+    Assignment,
+    Commit,
+    Deregistration,
+    Registration,
+    Unassignment,
+    Version,
+    VStage,
+)
+from tests.utils import check_obj
 
 
 def test_api(showcase):
@@ -29,44 +38,60 @@ def test_api(showcase):
     #     ["commits"],
     # )
     nn_artifact = artifacts["nn"]
-    assert isinstance(nn_artifact, BaseArtifact)
-    assert nn_artifact.name == "nn"
+    assert isinstance(nn_artifact, Artifact)
+    assert nn_artifact.artifact == "nn"
     assert len(nn_artifact.versions) == 2
     nn_version = nn_artifact.versions[0]
-    assert isinstance(nn_version, BaseVersion)
+    assert isinstance(nn_version, Version)
     author = repo.commit().author.name
     author_email = repo.commit().author.email
 
     skip_keys_registration = {
         "created_at",
-        "assignments",
+        "activated_at",
+        "registrations",
+        "deregistrations",
         "enrichments",
         "tag",
         "message",
+        "stages",
+    }
+    skip_keys_assignment = {
+        "created_at",
+        "message",
+        "assignments",
+        "unassignments",
+        "activated_at",
+        "priority",
+        "addition",
+        "event",
     }
-    skip_keys_assignment = {"created_at", "tag", "message"}
 
-    _check_obj(
-        nn_version,
+    check_obj(
+        nn_version.dict_state(),
         dict(
             artifact="nn",
-            name="v0.0.1",
+            version="v0.0.1",
             author=author,
             author_email=author_email,
             commit_hexsha=first_commit.hexsha,
             discovered=False,
+            is_active=True,
+            ref="nn@v0.0.1",
         ),
         skip_keys=skip_keys_registration,
     )
-    assert len(nn_artifact.stages) == 1
-    nn_assignment = nn_artifact.stages[0]
-    assert isinstance(nn_assignment, BaseAssignment)
-    _check_obj(
-        nn_assignment,
+    nn_vstages = nn_artifact.get_vstages()
+    assert len(nn_vstages) == 1
+    assert isinstance(nn_vstages["staging"][0], VStage)
+    check_obj(
+        nn_vstages["staging"][0].dict_state(),
         dict(
             artifact="nn",
             version="v0.0.1",
             stage="staging",
+            is_active=True,
+            ref="nn#staging#1",
             author=author,
             author_email=author_email,
             commit_hexsha=first_commit.hexsha,
@@ -75,17 +100,19 @@ def test_api(showcase):
     )
 
     rf_artifact = artifacts["rf"]
-    assert isinstance(rf_artifact, BaseArtifact)
-    assert rf_artifact.name == "rf"
+    assert isinstance(rf_artifact, Artifact)
+    assert rf_artifact.artifact == "rf"
 
     assert len(rf_artifact.versions) == 2
-    assert all(isinstance(v, BaseVersion) for v in rf_artifact.versions)
+    assert all(isinstance(v, Version) for v in rf_artifact.versions)
     rf_ver1, rf_ver2 = rf_artifact.versions
-    _check_obj(
-        rf_ver1,
+    check_obj(
+        rf_ver1.dict_state(),
         dict(
             artifact="rf",
-            name="v1.2.3",
+            version="v1.2.3",
+            is_active=True,
+            ref="rf@v1.2.3",
             author=author,
             author_email=author_email,
             commit_hexsha=first_commit.hexsha,
@@ -93,11 +120,13 @@ def test_api(showcase):
         ),
         skip_keys=skip_keys_registration,
     )
-    _check_obj(
-        rf_ver2,
+    check_obj(
+        rf_ver2.dict_state(),
         dict(
             artifact="rf",
-            name="v1.2.4",
+            version="v1.2.4",
+            is_active=True,
+            ref="rf@v1.2.4",
             author=author,
             author_email=author_email,
             commit_hexsha=second_commit.hexsha,
@@ -106,45 +135,62 @@ def test_api(showcase):
         skip_keys=skip_keys_registration,
     )
 
-    assert len(rf_artifact.stages) == 4
-    assert all(isinstance(p, BaseAssignment) for p in rf_artifact.stages)
-    rf_l1, _ = rf_ver1.assignments
-    rf_l3, rf_l4 = rf_ver2.assignments
+    assert len(rf_artifact.get_events()) == 8
+    assert all(
+        isinstance(p, (Assignment, Unassignment, Registration, Deregistration, Commit))
+        for p in rf_artifact.get_events()
+    )
+    assert all(
+        isinstance(p, (Registration, Deregistration))
+        for p in rf_ver1.get_events(indirect=False) + rf_ver2.get_events(indirect=False)
+    )
+    assert all(
+        isinstance(p, (Assignment, Unassignment, Commit))
+        for p in rf_ver1.get_events(direct=False) + rf_ver2.get_events(direct=False)
+    )
+    rf_a4, rf_a1, rf_c1 = rf_ver1.get_events(
+        direct=False
+    )  # pylint: disable=unused-variable
+    rf_a3, rf_a2, rf_c2 = rf_ver2.get_events(
+        direct=False
+    )  # pylint: disable=unused-variable
 
-    _check_obj(
-        rf_l1,
+    check_obj(
+        rf_a1.dict_state(),
         dict(
             artifact="rf",
             version="v1.2.3",
             stage="production",
+            tag="rf#production#1",
             author=author,
             author_email=author_email,
             commit_hexsha=first_commit.hexsha,
         ),
         skip_keys=skip_keys_assignment,
     )
-    _check_obj(
-        rf_l4,
+    check_obj(
+        rf_a3.dict_state(),
         dict(
             artifact="rf",
             version="v1.2.4",
             stage="production",
+            tag="rf#production#3",
             author=author,
             author_email=author_email,
             commit_hexsha=second_commit.hexsha,
         ),
         skip_keys=skip_keys_assignment,
     )
-    _check_obj(
-        rf_l3,
+    check_obj(
+        rf_a2.dict_state(),
         dict(
             artifact="rf",
             version="v1.2.4",
             stage="staging",
+            tag="rf#staging#2",
             author=author,
             author_email=author_email,
             commit_hexsha=second_commit.hexsha,
         ),
         skip_keys=skip_keys_assignment,
     )
-    assert gto.api.find_versions_in_stage(repo, "rf", "staging", all=True) == [rf_l3]
